"""Top-level package for qwak-proto."""

# fmt: off
__author__ = '''Qwak'''
__email__ = 'info@qwak.com'
__version__ = '0.0.315.dev0'
# fmt: on

from .di_configuration import wire_dependencies

_container = wire_dependencies()



from abc import ABC, abstractmethod
from dataclasses import dataclass, field
from enum import Enum
from typing import Dict, List

from _qwak_proto.qwak.automation.v1.action_pb2 import (
    Action as ActionProto,
    AdvancedDeploymentOptions,
    BuildAndDeployAction,
    BuildMetricCondition,
    BuildSpec,
    CpuResources as CpuResourcesProto,
    DeployedBuildMetricCondition as DeployedBuildMetricConditionProto,
    DeploymentCondition as DeploymentConditionProto,
    DeploymentSize,
    DeploymentSpec,
    GitModelSource,
    GpuResources as GpuResourceProto,
    GpuType,
    PurchaseOption as PurchaseOptionProto,
    Resources as ResourceProto,
)
from _qwak_proto.qwak.automation.v1.auto_scaling_pb2 import (
    AGGREGATION_TYPE_AVERAGE,
    AGGREGATION_TYPE_MAX,
    AGGREGATION_TYPE_MIN,
    AGGREGATION_TYPE_P50,
    AGGREGATION_TYPE_P90,
    AGGREGATION_TYPE_P95,
    AGGREGATION_TYPE_P99,
    AGGREGATION_TYPE_SUM,
    METRIC_TYPE_CPU,
    METRIC_TYPE_LATENCY,
    METRIC_TYPE_MEMORY,
    AutoScalingConfig as AutoScalingConfigProto,
    AutoScalingPrometheusTrigger as AutoScalingPrometheusTriggerProto,
    QuerySpec,
    ScaleTrigger as ScaleTriggerProto,
    Triggers as TriggersProto,
)
from _qwak_proto.qwak.user_application.common.v0.resources_pb2 import (
    ClientPodComputeResources,
    CpuResources as CommonCpuResourcesProto,
    GpuResources as CommonGpuResourcesProto,
    GpuType as CommonGpuTypeProto,
    PodComputeResourceTemplateSpec,
)
from google.protobuf.wrappers_pb2 import BoolValue
from qwak.automations.common import (
    Action,
    ThresholdDirection,
    get_memory_amount,
    map_common_memory_units,
    map_common_memory_units_proto,
    map_memory_units,
    map_memory_units_proto,
    map_proto_threshold_to_direction,
    map_threshold_direction_to_proto,
)


@dataclass
class DeploymentCondition(ABC):
    @abstractmethod
    def to_proto(self):
        # abstract method
        pass

    @staticmethod
    @abstractmethod
    def from_proto(message: DeploymentConditionProto):
        # abstract method
        pass


@dataclass
class AutoScaleTrigger(ABC):
    @abstractmethod
    def to_proto(self):
        # abstract method
        pass

    @staticmethod
    @abstractmethod
    def from_proto(message: ScaleTriggerProto):
        # abstract method
        pass


@dataclass
class DeployedBuildMetric(DeploymentCondition):
    metric_name: str = field(default="")
    direction: ThresholdDirection = field(default=ThresholdDirection.ABOVE)
    variation: str = field(default="default")

    def to_proto(self):
        return DeploymentConditionProto(
            deployed_build_metric=DeployedBuildMetricConditionProto(
                metric_name=self.metric_name,
                threshold_direction=map_threshold_direction_to_proto(self.direction),
                variation=self.variation,
            )
        )

    @staticmethod
    def from_proto(message: DeploymentConditionProto):
        return DeployedBuildMetric(
            metric_name=message.deployed_build_metric.metric_name,
            direction=map_proto_threshold_to_direction(
                message.deployed_build_metric.threshold_direction
            ),
            variation=message.deployed_build_metric.variation,
        )

    def __str__(self):
        return f"Metric Name: \tDirection: {self.direction.name}"


@dataclass
class BuildMetric(DeploymentCondition):
    metric_name: str = field(default="")
    direction: ThresholdDirection = field(default=ThresholdDirection.ABOVE)
    threshold: str = field(default="")

    def to_proto(self):
        return DeploymentConditionProto(
            build_metric=BuildMetricCondition(
                metric_name=self.metric_name,
                threshold=self.threshold,
                threshold_direction=map_threshold_direction_to_proto(self.direction),
            )
        )

    @staticmethod
    def from_proto(message: DeploymentConditionProto):
        return BuildMetric(
            metric_name=message.build_metric.metric_name,
            threshold=message.build_metric.threshold,
            direction=map_proto_threshold_to_direction(
                message.build_metric.threshold_direction
            ),
        )

    def __str__(self):
        return f"Metric Name: {self.metric_name}\tThreshold: {self.threshold}\tDirection: {self.direction.name}"


@dataclass
class Resources(ABC):
    @abstractmethod
    def to_proto(self):
        # abstract method
        pass

    @staticmethod
    @abstractmethod
    def from_proto(message: ResourceProto):
        # abstract method
        pass


@dataclass
class CpuResources(Resources):
    cpu_fraction: float = field(default=2)
    memory: str = field(default="2Gi")

    def to_proto(self):
        return ResourceProto(
            cpu_resources=CpuResourcesProto(
                cpu=self.cpu_fraction,
                memory_units=map_memory_units(memory=self.memory),
                memory_amount=get_memory_amount(self.memory),
            )
        )

    def to_common_proto(self):
        return CommonCpuResourcesProto(
            cpu=self.cpu_fraction,
            memory_units=map_common_memory_units(memory=self.memory),
            memory_amount=get_memory_amount(self.memory),
        )

    @staticmethod
    def from_proto(message: ResourceProto):
        return CpuResources(
            cpu_fraction=message.cpu_resources.cpu,
            memory=str(message.cpu_resources.memory_amount)
            + map_memory_units_proto(message.cpu_resources.memory_units),
        )

    @staticmethod
    def from_common_cpu_proto(message: CommonCpuResourcesProto):
        return CpuResources(
            cpu_fraction=message.cpu,
            memory=str(message.memory_amount)
            + map_common_memory_units_proto(message.memory_units),
        )

    def __str__(self):
        return f"CPU: {self.cpu_fraction}, Memory: {self.memory}"


@dataclass
class GpuResources(Resources):
    gpu_type: str = field(default=None)
    gpu_amount: int = field(default=None)

    def to_proto(self):
        return ResourceProto(
            gpu_resources=GpuResourceProto(
                gpu_type=self.gpu_type,
                gpu_amount=self.gpu_amount,
            )
        )

    def to_gpu_proto(self):
        return GpuResourceProto(
            gpu_type=self.gpu_type,
            gpu_amount=self.gpu_amount,
        )

    def to_common_gpu_proto(self):
        return CommonGpuResourcesProto(
            gpu_amount=self.gpu_amount, gpu_type=self.gpu_type
        )

    @staticmethod
    def from_proto(message: ResourceProto):
        return GpuResources(
            gpu_type=GpuType.Name(message.gpu_resources.gpu_type),
            gpu_amount=message.gpu_resources.gpu_amount,
        )

    @staticmethod
    def from_gpu_proto(message: GpuResourceProto):
        return GpuResources(
            gpu_type=GpuType.Name(message.gpu_type),
            gpu_amount=message.gpu_amount,
        )

    @staticmethod
    def from_common_gpu_proto(message: CommonGpuResourcesProto):
        return GpuResources(
            gpu_type=CommonGpuTypeProto.Name(message.gpu_type),
            gpu_amount=message.gpu_amount,
        )

    def __str__(self):
        return f"GPU Type: {self.gpu_type}, GPU Amount: {self.gpu_amount}"


@dataclass
class ClientResources(Resources):
    instance: str = field(default="")
    gpu_resources: GpuResources = field(default=None)
    cpu_resources: CpuResources = field(default=None)

    def to_proto(self):
        if self.instance:
            client_pod_compute_resources = ClientPodComputeResources(
                template_spec=PodComputeResourceTemplateSpec(template_id=self.instance)
            )
        elif self.gpu_resources:
            client_pod_compute_resources = ClientPodComputeResources(
                gpu_resources=self.gpu_resources.to_common_gpu_proto()
            )
        elif self.cpu_resources:
            client_pod_compute_resources = ClientPodComputeResources(
                cpu_resources=self.cpu_resources.to_common_proto()
            )
        else:
            client_pod_compute_resources = ClientPodComputeResources()

        return ResourceProto(client_pod_compute_resources=client_pod_compute_resources)

    @staticmethod
    def from_proto(message: ResourceProto):
        resources_type = message.client_pod_compute_resources.WhichOneof("resources")
        if resources_type == "template_spec":
            return ClientResources(
                instance=message.client_pod_compute_resources.template_spec.template_id
            )
        elif resources_type == "gpu_resources":
            return ClientResources(
                gpu_resources=GpuResources.from_common_gpu_proto(
                    message.client_pod_compute_resources.gpu_resources
                )
            )
        else:
            return ClientResources(
                cpu_resources=CpuResources.from_common_cpu_proto(
                    message.client_pod_compute_resources.cpu_resources
                )
            )


@dataclass
class BuildSpecifications:
    parameters: Dict[str, str] = field(default_factory=dict)
    git_uri: str = field(default=None)
    tags: List[str] = field(default_factory=list)
    git_access_token_secret: str = field(default=None)
    git_branch: str = field(default="main")
    main_dir: str = field(default="main")
    base_image: str = field(default="")
    assumed_iam_role: str = field(default="")
    resources: Resources = field(default_factory=CpuResources)
    dependency_file_path: str = field(default=None)
    env_vars: List[str] = field(default_factory=list)
    git_ssh_token_secret: str = field(default=None)
    gpu_compatible: bool = field(default=False)
    push_image: bool = field(default=True)
    purchase_option: str = field(default="spot")
    provision_instance_timeout: int = field(default=120)
    service_account_key_secret_name: str = field(default="")

    def to_proto(self):
        return BuildSpec(
            parameters=self.parameters,
            git_model_source=GitModelSource(
                git_uri=self.git_uri,
                git_credentials_secret_name=self.git_access_token_secret,
                git_branch=self.git_branch,
                git_ssh_secret_name=self.git_ssh_token_secret,
            ),
            main_dir=self.main_dir,
            tags=self.tags,
            resource=self.resources.to_proto(),
            base_image=self.base_image,
            assumed_iam_role=self.assumed_iam_role,
            dependency_file_path=self.dependency_file_path,
            env_vars=self.env_vars,
            gpu_compatible=self.gpu_compatible,
            push_image=BoolValue(value=self.push_image),
            purchase_option=self.__purchase_option_to_proto(),
            provision_instance_timeout=self.provision_instance_timeout,
            service_account_key_secret_name=self.service_account_key_secret_name,
        )

    def __purchase_option_to_proto(self):
        purchase_option = self.purchase_option.lower()
        if purchase_option == "spot":
            return PurchaseOptionProto.SPOT
        elif purchase_option == "ondemand":
            return PurchaseOptionProto.ON_DEMAND
        else:
            raise ValueError(
                f"Invalid purchase option {self.purchase_option}. Purchase options can be either spot or ondemand"
            )

    @staticmethod
    def from_proto(build_spec: BuildSpec):
        resources = map_resources_name_to_class(
            build_spec.resource.WhichOneof("resource")
        )
        push_image = True
        if build_spec.HasField("push_image"):
            push_image = build_spec.push_image.value

        return BuildSpecifications(
            parameters=build_spec.parameters,
            git_uri=build_spec.git_model_source.git_uri,
            git_access_token_secret=build_spec.git_model_source.git_credentials_secret_name,
            git_branch=build_spec.git_model_source.git_branch,
            tags=build_spec.tags,
            main_dir=build_spec.main_dir,
            base_image=build_spec.base_image,
            resources=resources.from_proto(build_spec.resource) if resources else None,
            dependency_file_path=build_spec.dependency_file_path,
            assumed_iam_role=build_spec.assumed_iam_role,
            env_vars=build_spec.env_vars,
            git_ssh_token_secret=build_spec.git_model_source.git_ssh_secret_name,
            gpu_compatible=build_spec.gpu_compatible,
            push_image=push_image,
            purchase_option=BuildSpecifications.__purchase_option_from_proto(
                build_spec.purchase_option
            ),
            service_account_key_secret_name=build_spec.service_account_key_secret_name,
            provision_instance_timeout=build_spec.provision_instance_timeout,
        )

    @staticmethod
    def __purchase_option_from_proto(purchase_option: PurchaseOptionProto):
        if purchase_option == PurchaseOptionProto.SPOT:
            return "spot"
        elif purchase_option == PurchaseOptionProto.ON_DEMAND:
            return "ondemand"
        else:
            raise ValueError(
                f"Invalid purchase option {purchase_option}. Purchase options can be either spot or ondemand"
            )

    def __str__(self):
        result = f"Git Uri:\t{self.git_uri}\n"
        result += f"Git Branch:\t{self.git_branch}\n"
        result += (
            f"Git Access Token Secret:\t{self.git_access_token_secret}\n"
            if self.git_access_token_secret
            else ""
        )
        result += (
            f"Git Ssh Secret:\t{self.git_ssh_token_secret}\n"
            if self.git_ssh_token_secret
            else ""
        )
        result += f"Main Dir:\t{self.main_dir}\n" if self.main_dir != "main" else ""
        result += f"Gpu Compatible:\t{self.gpu_compatible}\n"
        result += f"Purchase Option:\t{self.purchase_option}\n"
        result += f"Provision Instance Timeout:\t{self.provision_instance_timeout}\n"
        result += f"Parameters:\t{self.parameters}\n" if self.parameters else ""
        result += f"Tags:\t{self.tags}\n" if self.tags else ""
        result += (
            f"IAM Role:\t{self.assumed_iam_role}\n" if self.assumed_iam_role else ""
        )
        result += (
            f"Service Account Key Secret Name:\t{self.service_account_key_secret_name}\n"
            if self.service_account_key_secret_name
            else ""
        )
        result += f"Base Image:\t{self.base_image}\n" if self.base_image else ""
        result += f"Resources:\n{self.resources}\n" if self.resources else ""
        result += f"Environment Variables:\n{self.env_vars}\n" if self.env_vars else ""
        return result


class MetricType(Enum):
    cpu = METRIC_TYPE_CPU
    latency = METRIC_TYPE_LATENCY
    memory = METRIC_TYPE_MEMORY


class AggregationType(Enum):
    avg = AGGREGATION_TYPE_AVERAGE
    max = AGGREGATION_TYPE_MAX
    min = AGGREGATION_TYPE_MIN
    sum = AGGREGATION_TYPE_SUM
    p50 = AGGREGATION_TYPE_P50
    p90 = AGGREGATION_TYPE_P90
    p95 = AGGREGATION_TYPE_P95
    p99 = AGGREGATION_TYPE_P99


@dataclass
class AutoScalingConfig:
    min_replica_count: int = field(default=None)
    max_replica_count: int = field(default=None)
    polling_interval: int = field(default=None)
    cool_down_period: int = field(default=None)
    triggers: List[AutoScaleTrigger] = field(default_factory=list)

    def to_proto(self):
        return AutoScalingConfigProto(
            min_replica_count=self.min_replica_count,
            max_replica_count=self.max_replica_count,
            polling_interval=self.polling_interval,
            cool_down_period=self.cool_down_period,
            triggers=TriggersProto(
                triggers=[trigger.to_proto() for trigger in self.triggers]
            ),
        )

    @staticmethod
    def from_proto(message: AutoScalingConfigProto):
        triggers = [
            map_autoscaling_trigger_name_to_class(
                trigger.WhichOneof("trigger_type")
            ).from_proto(trigger)
            for trigger in message.triggers.triggers
        ]
        return AutoScalingConfig(
            min_replica_count=message.min_replica_count,
            max_replica_count=message.max_replica_count,
            polling_interval=message.polling_interval,
            cool_down_period=message.cool_down_period,
            triggers=triggers,
        )

    def __str__(self):
        result = f"min replica count: {self.min_replica_count} \t max replica count: {self.max_replica_count} \t polling interval: {self.polling_interval} \t cool down period: {self.cool_down_period} \n"
        result += "Scale triggers: "
        for trigger in self.triggers:
            result += f" {trigger}"
        return result


@dataclass
class DeploymentSpecifications:
    number_of_http_server_workers: int = field(default=2)
    http_request_timeout_ms: int = field(default=5000)
    max_batch_size: int = field(default=1)
    daemon_mode: bool = field(default=False)
    variation_name: str = field(default="default")
    custom_iam_role_arn: str = field(default="")
    number_of_pods: int = field(default=2)
    cpu_fraction: float = field(default=2)
    memory: str = field(default="2Gi")
    gpu_resources: GpuResources = field(default=None)
    auto_scale_config: AutoScalingConfig = field(default_factory=AutoScalingConfig)
    environments: List[str] = field(default_factory=list)
    env_vars: List[str] = field(default_factory=list)
    deployment_timeout: int = field(default=0)
    instance: str = field(default="")
    service_account_key_secret_name: str = field(default="")

    def to_proto(self):
        deployment_size = self.__get_deployment_size_proto()
        return DeploymentSpec(
            selected_variation_name=self.variation_name,
            deployment_size=deployment_size,
            advanced_options=AdvancedDeploymentOptions(
                number_of_http_server_workers=self.number_of_http_server_workers,
                http_request_timeout_ms=self.http_request_timeout_ms,
                max_batch_size=self.max_batch_size,
                daemon_mode=self.daemon_mode,
                custom_iam_role_arn=self.custom_iam_role_arn,
                auto_scaling_config=self.auto_scale_config.to_proto(),
                deployment_process_timeout_limit=self.deployment_timeout,
                service_account_key_secret_name=self.service_account_key_secret_name,
            ),
            environments=self.environments,
            env_vars=self.env_vars,
        )

    @staticmethod
    def from_proto(message: DeploymentSpec):
        if (
            (
                message.deployment_size.client_pod_compute_resources.cpu_resources
                and message.deployment_size.client_pod_compute_resources.cpu_resources.cpu
                > 0
            )
            or (
                message.deployment_size.client_pod_compute_resources.gpu_resources
                and message.deployment_size.client_pod_compute_resources.gpu_resources.gpu_amount
                > 0
            )
            or (
                message.deployment_size.client_pod_compute_resources.template_spec
                and message.deployment_size.client_pod_compute_resources.template_spec.template_id
            )
        ):
            return DeploymentSpecifications.__from_proto_common_resources(message)
        else:
            return DeploymentSpecifications.__from_proto_deprecated_resources(message)

    def __str__(self):
        result = self.__get_deployment_resources_output()
        result += (
            f"Number of HTTP Workers: {self.number_of_http_server_workers}\t"
            f"HTTP Request Timeout: {self.http_request_timeout_ms}\t"
            f"Daemon Mode: {self.daemon_mode}\t"
            f"Max Batch Size: {self.max_batch_size}\n"
        )
        result += f"Environment Variables: {self.env_vars}\n"
        result += (
            f"Custom IAM Role: {self.custom_iam_role_arn}"
            if self.custom_iam_role_arn
            else ""
        )
        result += (
            f"Custom Service Account Key Secret Name: {self.service_account_key_secret_name}\n"
            if self.service_account_key_secret_name
            else ""
        )
        result += f"Auto scaling config: {self.auto_scale_config}"
        return result

    def __get_deployment_resources_output(self) -> str:
        result = f"Number of Pods: {self.number_of_pods}\t"
        if self.instance:
            result += f"Instance: {self.instance}\n"
        elif self.gpu_resources and self.gpu_resources.gpu_amount > 0:
            result += (
                f"GPU: {self.gpu_resources.gpu_amount}\t"
                f"Type: {self.gpu_resources.gpu_type}\n"
            )
        else:
            result += f"CPU: {self.cpu_fraction}\tMemory: {self.memory}\n"

        return result

    def __get_deployment_size_proto(self) -> DeploymentSize:
        if self.instance:
            client_pod_compute_resources = ClientPodComputeResources(
                template_spec=PodComputeResourceTemplateSpec(template_id=self.instance)
            )
        elif self.gpu_resources and self.gpu_resources.gpu_amount > 0:
            client_pod_compute_resources = ClientPodComputeResources(
                gpu_resources=CommonGpuResourcesProto(
                    gpu_amount=self.gpu_resources.gpu_amount,
                    gpu_type=self.gpu_resources.gpu_type,
                )
            )
        else:
            client_pod_compute_resources = ClientPodComputeResources(
                cpu_resources=CommonCpuResourcesProto(
                    cpu=self.cpu_fraction,
                    memory_amount=get_memory_amount(self.memory),
                    memory_units=map_common_memory_units(self.memory),
                )
            )
        return DeploymentSize(
            number_of_pods=self.number_of_pods,
            client_pod_compute_resources=client_pod_compute_resources,
            cpu=self.cpu_fraction,
            memory_units=map_memory_units(memory=self.memory),
            memory_amount=get_memory_amount(self.memory),
            gpu_resources=(
                self.gpu_resources.to_gpu_proto() if self.gpu_resources else None
            ),
        )

    @staticmethod
    def __from_proto_common_resources(message):
        return DeploymentSpecifications(
            variation_name=message.selected_variation_name,
            number_of_http_server_workers=message.advanced_options.number_of_http_server_workers,
            http_request_timeout_ms=message.advanced_options.http_request_timeout_ms,
            max_batch_size=message.advanced_options.max_batch_size,
            daemon_mode=message.advanced_options.daemon_mode,
            custom_iam_role_arn=message.advanced_options.custom_iam_role_arn,
            number_of_pods=message.deployment_size.number_of_pods,
            cpu_fraction=message.deployment_size.client_pod_compute_resources.cpu_resources.cpu,
            memory=str(
                message.deployment_size.client_pod_compute_resources.cpu_resources.memory_amount
            )
            + map_common_memory_units_proto(
                message.deployment_size.client_pod_compute_resources.cpu_resources.memory_units
            ),
            gpu_resources=(
                GpuResources.from_common_gpu_proto(
                    message.deployment_size.client_pod_compute_resources.gpu_resources
                )
                if (
                    message.deployment_size.client_pod_compute_resources.gpu_resources
                    and message.deployment_size.client_pod_compute_resources.gpu_resources.gpu_amount
                    > 0
                )
                else None
            ),
            instance=(
                message.deployment_size.client_pod_compute_resources.template_spec.template_id
                if message.deployment_size.client_pod_compute_resources.template_spec.template_id
                else ""
            ),
            auto_scale_config=AutoScalingConfig.from_proto(
                message.advanced_options.auto_scaling_config
            ),
            environments=message.environments,
            env_vars=message.env_vars,
            deployment_timeout=message.advanced_options.deployment_process_timeout_limit,
            service_account_key_secret_name=message.advanced_options.service_account_key_secret_name,
        )

    @staticmethod
    def __from_proto_deprecated_resources(message):
        return DeploymentSpecifications(
            variation_name=message.selected_variation_name,
            number_of_http_server_workers=message.advanced_options.number_of_http_server_workers,
            http_request_timeout_ms=message.advanced_options.http_request_timeout_ms,
            max_batch_size=message.advanced_options.max_batch_size,
            daemon_mode=message.advanced_options.daemon_mode,
            custom_iam_role_arn=message.advanced_options.custom_iam_role_arn,
            number_of_pods=message.deployment_size.number_of_pods,
            cpu_fraction=message.deployment_size.cpu,
            memory=str(message.deployment_size.memory_amount)
            + map_memory_units_proto(message.deployment_size.memory_units),
            gpu_resources=(
                GpuResources.from_gpu_proto(message.deployment_size.gpu_resources)
                if message.deployment_size.gpu_resources
                else None
            ),
            auto_scale_config=AutoScalingConfig.from_proto(
                message.advanced_options.auto_scaling_config
            ),
            environments=message.environments,
            env_vars=message.env_vars,
            deployment_timeout=message.advanced_options.deployment_process_timeout_limit,
            service_account_key_secret_name=message.advanced_options.service_account_key_secret_name,
        )


@dataclass
class QwakBuildDeploy(Action):
    build_spec: BuildSpecifications
    deployment_condition: DeploymentCondition
    deployment_spec: DeploymentSpecifications

    def to_proto(self):
        return ActionProto(
            build_deploy=BuildAndDeployAction(
                build_spec=self.build_spec.to_proto(),
                deployment_spec=self.deployment_spec.to_proto(),
                deployment_condition=self.deployment_condition.to_proto(),
            )
        )

    @staticmethod
    def from_proto(message: ActionProto):
        deployment_condition = map_deployment_condition_name_to_class(
            message.build_deploy.deployment_condition.WhichOneof("condition")
        )
        return QwakBuildDeploy(
            build_spec=BuildSpecifications.from_proto(message.build_deploy.build_spec),
            deployment_spec=DeploymentSpecifications.from_proto(
                message.build_deploy.deployment_spec
            ),
            deployment_condition=(
                deployment_condition.from_proto(
                    message.build_deploy.deployment_condition
                )
                if deployment_condition
                else None
            ),
        )

    def __str__(self):
        return f"Build Specifications:\n{self.build_spec}\nDeployment Specification:\n{self.deployment_spec}\nDeployment Condition:\n{self.deployment_condition}"


@dataclass
class AutoScaleQuerySpec:
    metric_type: str = field(default=None)
    aggregation_type: str = field(default=None)
    time_period: int = field(default=None)

    def to_proto(self):
        return QuerySpec(
            time_period=self.time_period,
            metric_type=MetricType[self.metric_type.lower()].value,
            aggregation_type=AggregationType[self.aggregation_type.lower()].value,
        )

    @staticmethod
    def from_proto(message: QuerySpec):
        return AutoScaleQuerySpec(
            metric_type=map_auto_scaling_metric_type_proto_to_name(message.metric_type),
            aggregation_type=map_aggregation_type_proto_to_name(
                message.aggregation_type
            ),
            time_period=message.time_period,
        )

    def __str__(self):
        return f"metric type: {self.metric_type}\taggregation type: {self.aggregation_type}\ttime period: {self.time_period}"


@dataclass
class AutoScalingPrometheusTrigger(AutoScaleTrigger):
    query_spec: AutoScaleQuerySpec = field(default=QuerySpec)
    threshold: int = field(default=None)

    def to_proto(self):
        return ScaleTriggerProto(
            prometheus_trigger=AutoScalingPrometheusTriggerProto(
                query_spec=self.query_spec.to_proto(), threshold=self.threshold
            )
        )

    @staticmethod
    def from_proto(message: ScaleTriggerProto):
        return AutoScalingPrometheusTrigger(
            threshold=message.prometheus_trigger.threshold,
            query_spec=AutoScaleQuerySpec.from_proto(
                message.prometheus_trigger.query_spec
            ),
        )

    def __str__(self):
        return f"threshold: {self.threshold} \t {self.query_spec}"


def map_resources_name_to_class(resource_name: str):
    mapping = {
        "cpu_resources": CpuResources,
        "gpu_resources": GpuResources,
        "client_pod_compute_resources": ClientResources,
    }
    return mapping.get(resource_name)


def map_deployment_condition_name_to_class(deployment_condition_name: str):
    mapping = {
        "build_metric": BuildMetric,
        "deployed_build_metric": DeployedBuildMetric,
    }
    return mapping.get(deployment_condition_name)


def map_auto_scaling_metric_type_proto_to_name(metric_type):
    mapping = {
        METRIC_TYPE_CPU: "cpu",
        METRIC_TYPE_LATENCY: "latency",
        METRIC_TYPE_MEMORY: "memory",
    }
    return mapping.get(metric_type)


def map_aggregation_type_proto_to_name(aggregation_type):
    mapping = {
        AGGREGATION_TYPE_AVERAGE: "avg",
        AGGREGATION_TYPE_MAX: "max",
        AGGREGATION_TYPE_MIN: "min",
        AGGREGATION_TYPE_SUM: "sum",
        AGGREGATION_TYPE_P50: "p50",
        AGGREGATION_TYPE_P90: "p90",
        AGGREGATION_TYPE_P95: "p95",
        AGGREGATION_TYPE_P99: "p99",
    }
    return mapping.get(aggregation_type)


def map_autoscaling_trigger_name_to_class(auto_scaling_trigger_name: str):
    mapping = {"prometheus_trigger": AutoScalingPrometheusTrigger}
    return mapping.get(auto_scaling_trigger_name)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/instance_template/instance_template_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.instance_template import instance_template_pb2 as qwak_dot_instance__template_dot_instance__template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6qwak/instance_template/instance_template_service.proto\x12!qwak.management.instance_template\x1a.qwak/instance_template/instance_template.proto\"s\n\x1cListInstanceTemplatesRequest\x12S\n\x18optional_instance_filter\x18\x01 \x01(\x0b\x32\x31.qwak.management.instance_template.InstanceFilter\"x\n\x1dListInstanceTemplatesResponse\x12W\n\x16instance_template_list\x18\x01 \x03(\x0b\x32\x37.qwak.management.instance_template.InstanceTemplateSpec\"(\n\x1aGetInstanceTemplateRequest\x12\n\n\x02id\x18\x01 \x01(\t\"q\n\x1bGetInstanceTemplateResponse\x12R\n\x11instance_template\x18\x01 \x01(\x0b\x32\x37.qwak.management.instance_template.InstanceTemplateSpec2\xd7\x02\n!InstanceTemplateManagementService\x12\x9a\x01\n\x15ListInstanceTemplates\x12?.qwak.management.instance_template.ListInstanceTemplatesRequest\x1a@.qwak.management.instance_template.ListInstanceTemplatesResponse\x12\x94\x01\n\x13GetInstanceTemplate\x12=.qwak.management.instance_template.GetInstanceTemplateRequest\x1a>.qwak.management.instance_template.GetInstanceTemplateResponseB0\n,com.qwak.ai.management.instance_template.apiP\x01\x62\x06proto3')



_LISTINSTANCETEMPLATESREQUEST = DESCRIPTOR.message_types_by_name['ListInstanceTemplatesRequest']
_LISTINSTANCETEMPLATESRESPONSE = DESCRIPTOR.message_types_by_name['ListInstanceTemplatesResponse']
_GETINSTANCETEMPLATEREQUEST = DESCRIPTOR.message_types_by_name['GetInstanceTemplateRequest']
_GETINSTANCETEMPLATERESPONSE = DESCRIPTOR.message_types_by_name['GetInstanceTemplateResponse']
ListInstanceTemplatesRequest = _reflection.GeneratedProtocolMessageType('ListInstanceTemplatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCETEMPLATESREQUEST,
  '__module__' : 'qwak.instance_template.instance_template_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.instance_template.ListInstanceTemplatesRequest)
  })
_sym_db.RegisterMessage(ListInstanceTemplatesRequest)

ListInstanceTemplatesResponse = _reflection.GeneratedProtocolMessageType('ListInstanceTemplatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCETEMPLATESRESPONSE,
  '__module__' : 'qwak.instance_template.instance_template_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.instance_template.ListInstanceTemplatesResponse)
  })
_sym_db.RegisterMessage(ListInstanceTemplatesResponse)

GetInstanceTemplateRequest = _reflection.GeneratedProtocolMessageType('GetInstanceTemplateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCETEMPLATEREQUEST,
  '__module__' : 'qwak.instance_template.instance_template_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.instance_template.GetInstanceTemplateRequest)
  })
_sym_db.RegisterMessage(GetInstanceTemplateRequest)

GetInstanceTemplateResponse = _reflection.GeneratedProtocolMessageType('GetInstanceTemplateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCETEMPLATERESPONSE,
  '__module__' : 'qwak.instance_template.instance_template_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.instance_template.GetInstanceTemplateResponse)
  })
_sym_db.RegisterMessage(GetInstanceTemplateResponse)

_INSTANCETEMPLATEMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['InstanceTemplateManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,com.qwak.ai.management.instance_template.apiP\001'
  _LISTINSTANCETEMPLATESREQUEST._serialized_start=141
  _LISTINSTANCETEMPLATESREQUEST._serialized_end=256
  _LISTINSTANCETEMPLATESRESPONSE._serialized_start=258
  _LISTINSTANCETEMPLATESRESPONSE._serialized_end=378
  _GETINSTANCETEMPLATEREQUEST._serialized_start=380
  _GETINSTANCETEMPLATEREQUEST._serialized_end=420
  _GETINSTANCETEMPLATERESPONSE._serialized_start=422
  _GETINSTANCETEMPLATERESPONSE._serialized_end=535
  _INSTANCETEMPLATEMANAGEMENTSERVICE._serialized_start=538
  _INSTANCETEMPLATEMANAGEMENTSERVICE._serialized_end=881
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/projects/projects.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.models import models_pb2 as qwak_dot_models_dot_models__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cqwak/projects/projects.proto\x12\x18qwak.projects.management\x1a\x18qwak/models/models.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x91\x01\n\x14\x43reateProjectRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x1b\n\x13project_description\x18\x02 \x01(\t\x12\x46\n\njfrog_spec\x18\x03 \x01(\x0b\x32\x32.qwak.projects.management.ModelRepositoryJFrogSpec\"O\n\x15\x43reateProjectResponse\x12\x36\n\x07project\x18\x01 \x01(\x0b\x32%.qwak.projects.management.ProjectSpec\"\x15\n\x13ListProjectsRequest\"O\n\x14ListProjectsResponse\x12\x37\n\x08projects\x18\x01 \x03(\x0b\x32%.qwak.projects.management.ProjectSpec\"=\n\x11GetProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x14\n\x0cproject_name\x18\x02 \x01(\t\"H\n\x12GetProjectResponse\x12\x32\n\x07project\x18\x01 \x01(\x0b\x32!.qwak.projects.management.Project\"*\n\x14\x44\x65leteProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"%\n\x15\x44\x65leteProjectResponse\x12\x0c\n\x04info\x18\x01 \x01(\t\"{\n\x14UpdateProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12O\n\x13project_spec_config\x18\x02 \x01(\x0b\x32\x32.qwak.projects.management.ProjectSpecConfiguration\"T\n\x15UpdateProjectResponse\x12;\n\x0cproject_spec\x18\x01 \x01(\x0b\x32%.qwak.projects.management.ProjectSpec\"\xac\x01\n\x07Project\x12\x33\n\x04spec\x18\x01 \x01(\x0b\x32%.qwak.projects.management.ProjectSpec\x12\x31\n\x06models\x18\x02 \x03(\x0b\x32\x1d.qwak.models.management.ModelB\x02\x18\x01\x12\x39\n\rmodels_briefs\x18\x03 \x03(\x0b\x32\".qwak.models.management.ModelBrief\"\xeb\x03\n\x0bProjectSpec\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x14\n\x0cproject_name\x18\x02 \x01(\t\x12\x1b\n\x13project_description\x18\x03 \x01(\t\x12\x44\n\x0eproject_status\x18\x04 \x01(\x0e\x32,.qwak.projects.management.ProjectSpec.Status\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x34\n\x10last_modified_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x08 \x01(\t\x12\x14\n\x0cmodels_count\x18\t \x01(\x05\x12\x15\n\rmodels_active\x18\n \x01(\x05\x12N\n\x0ejfrog_settings\x18\x0b \x01(\x0b\x32\x36.qwak.projects.management.ModelRepositoryJFrogSettings\">\n\x06Status\x12\x0b\n\x07INVALID\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\r\n\tSUSPENDED\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\"M\n\x18ProjectSpecConfiguration\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x1b\n\x13project_description\x18\x02 \x01(\t\"\xd0\x01\n\x1cModelRepositoryJFrogSettings\x12S\n\x11pull_image_secret\x18\x01 \x01(\x0b\x32\x38.qwak.projects.management.ModelRepositoryPullImageSecret\x12[\n\x15jfrog_project_details\x18\x02 \x01(\x0b\x32<.qwak.projects.management.ModelRepositoryJFrogProjectDetails\"@\n\x1eModelRepositoryPullImageSecret\x12\x1e\n\x16pull_image_secret_name\x18\x01 \x01(\t\"?\n\"ModelRepositoryJFrogProjectDetails\x12\x19\n\x11jfrog_project_key\x18\x01 \x01(\t\"S\n\x18ModelRepositoryJFrogSpec\x12\x1b\n\x11jfrog_project_key\x18\x01 \x01(\tH\x00\x42\x1a\n\x18jfrog_project_identifier2\xc9\x04\n\x19ProjectsManagementService\x12p\n\rCreateProject\x12..qwak.projects.management.CreateProjectRequest\x1a/.qwak.projects.management.CreateProjectResponse\x12m\n\x0cListProjects\x12-.qwak.projects.management.ListProjectsRequest\x1a..qwak.projects.management.ListProjectsResponse\x12g\n\nGetProject\x12+.qwak.projects.management.GetProjectRequest\x1a,.qwak.projects.management.GetProjectResponse\x12p\n\rDeleteProject\x12..qwak.projects.management.DeleteProjectRequest\x1a/.qwak.projects.management.DeleteProjectResponse\x12p\n\rUpdateProject\x12..qwak.projects.management.UpdateProjectRequest\x1a/.qwak.projects.management.UpdateProjectResponseB\'\n#com.qwak.ai.management.projects.apiP\x01\x62\x06proto3')



_CREATEPROJECTREQUEST = DESCRIPTOR.message_types_by_name['CreateProjectRequest']
_CREATEPROJECTRESPONSE = DESCRIPTOR.message_types_by_name['CreateProjectResponse']
_LISTPROJECTSREQUEST = DESCRIPTOR.message_types_by_name['ListProjectsRequest']
_LISTPROJECTSRESPONSE = DESCRIPTOR.message_types_by_name['ListProjectsResponse']
_GETPROJECTREQUEST = DESCRIPTOR.message_types_by_name['GetProjectRequest']
_GETPROJECTRESPONSE = DESCRIPTOR.message_types_by_name['GetProjectResponse']
_DELETEPROJECTREQUEST = DESCRIPTOR.message_types_by_name['DeleteProjectRequest']
_DELETEPROJECTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteProjectResponse']
_UPDATEPROJECTREQUEST = DESCRIPTOR.message_types_by_name['UpdateProjectRequest']
_UPDATEPROJECTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateProjectResponse']
_PROJECT = DESCRIPTOR.message_types_by_name['Project']
_PROJECTSPEC = DESCRIPTOR.message_types_by_name['ProjectSpec']
_PROJECTSPECCONFIGURATION = DESCRIPTOR.message_types_by_name['ProjectSpecConfiguration']
_MODELREPOSITORYJFROGSETTINGS = DESCRIPTOR.message_types_by_name['ModelRepositoryJFrogSettings']
_MODELREPOSITORYPULLIMAGESECRET = DESCRIPTOR.message_types_by_name['ModelRepositoryPullImageSecret']
_MODELREPOSITORYJFROGPROJECTDETAILS = DESCRIPTOR.message_types_by_name['ModelRepositoryJFrogProjectDetails']
_MODELREPOSITORYJFROGSPEC = DESCRIPTOR.message_types_by_name['ModelRepositoryJFrogSpec']
_PROJECTSPEC_STATUS = _PROJECTSPEC.enum_types_by_name['Status']
CreateProjectRequest = _reflection.GeneratedProtocolMessageType('CreateProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTREQUEST,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.CreateProjectRequest)
  })
_sym_db.RegisterMessage(CreateProjectRequest)

CreateProjectResponse = _reflection.GeneratedProtocolMessageType('CreateProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTRESPONSE,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.CreateProjectResponse)
  })
_sym_db.RegisterMessage(CreateProjectResponse)

ListProjectsRequest = _reflection.GeneratedProtocolMessageType('ListProjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSREQUEST,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.ListProjectsRequest)
  })
_sym_db.RegisterMessage(ListProjectsRequest)

ListProjectsResponse = _reflection.GeneratedProtocolMessageType('ListProjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSRESPONSE,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.ListProjectsResponse)
  })
_sym_db.RegisterMessage(ListProjectsResponse)

GetProjectRequest = _reflection.GeneratedProtocolMessageType('GetProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTREQUEST,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.GetProjectRequest)
  })
_sym_db.RegisterMessage(GetProjectRequest)

GetProjectResponse = _reflection.GeneratedProtocolMessageType('GetProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTRESPONSE,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.GetProjectResponse)
  })
_sym_db.RegisterMessage(GetProjectResponse)

DeleteProjectRequest = _reflection.GeneratedProtocolMessageType('DeleteProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROJECTREQUEST,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.DeleteProjectRequest)
  })
_sym_db.RegisterMessage(DeleteProjectRequest)

DeleteProjectResponse = _reflection.GeneratedProtocolMessageType('DeleteProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROJECTRESPONSE,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.DeleteProjectResponse)
  })
_sym_db.RegisterMessage(DeleteProjectResponse)

UpdateProjectRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTREQUEST,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.UpdateProjectRequest)
  })
_sym_db.RegisterMessage(UpdateProjectRequest)

UpdateProjectResponse = _reflection.GeneratedProtocolMessageType('UpdateProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTRESPONSE,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.UpdateProjectResponse)
  })
_sym_db.RegisterMessage(UpdateProjectResponse)

Project = _reflection.GeneratedProtocolMessageType('Project', (_message.Message,), {
  'DESCRIPTOR' : _PROJECT,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.Project)
  })
_sym_db.RegisterMessage(Project)

ProjectSpec = _reflection.GeneratedProtocolMessageType('ProjectSpec', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTSPEC,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.ProjectSpec)
  })
_sym_db.RegisterMessage(ProjectSpec)

ProjectSpecConfiguration = _reflection.GeneratedProtocolMessageType('ProjectSpecConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTSPECCONFIGURATION,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.ProjectSpecConfiguration)
  })
_sym_db.RegisterMessage(ProjectSpecConfiguration)

ModelRepositoryJFrogSettings = _reflection.GeneratedProtocolMessageType('ModelRepositoryJFrogSettings', (_message.Message,), {
  'DESCRIPTOR' : _MODELREPOSITORYJFROGSETTINGS,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.ModelRepositoryJFrogSettings)
  })
_sym_db.RegisterMessage(ModelRepositoryJFrogSettings)

ModelRepositoryPullImageSecret = _reflection.GeneratedProtocolMessageType('ModelRepositoryPullImageSecret', (_message.Message,), {
  'DESCRIPTOR' : _MODELREPOSITORYPULLIMAGESECRET,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.ModelRepositoryPullImageSecret)
  })
_sym_db.RegisterMessage(ModelRepositoryPullImageSecret)

ModelRepositoryJFrogProjectDetails = _reflection.GeneratedProtocolMessageType('ModelRepositoryJFrogProjectDetails', (_message.Message,), {
  'DESCRIPTOR' : _MODELREPOSITORYJFROGPROJECTDETAILS,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.ModelRepositoryJFrogProjectDetails)
  })
_sym_db.RegisterMessage(ModelRepositoryJFrogProjectDetails)

ModelRepositoryJFrogSpec = _reflection.GeneratedProtocolMessageType('ModelRepositoryJFrogSpec', (_message.Message,), {
  'DESCRIPTOR' : _MODELREPOSITORYJFROGSPEC,
  '__module__' : 'qwak.projects.projects_pb2'
  # @@protoc_insertion_point(class_scope:qwak.projects.management.ModelRepositoryJFrogSpec)
  })
_sym_db.RegisterMessage(ModelRepositoryJFrogSpec)

_PROJECTSMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['ProjectsManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.management.projects.apiP\001'
  _PROJECT.fields_by_name['models']._options = None
  _PROJECT.fields_by_name['models']._serialized_options = b'\030\001'
  _CREATEPROJECTREQUEST._serialized_start=118
  _CREATEPROJECTREQUEST._serialized_end=263
  _CREATEPROJECTRESPONSE._serialized_start=265
  _CREATEPROJECTRESPONSE._serialized_end=344
  _LISTPROJECTSREQUEST._serialized_start=346
  _LISTPROJECTSREQUEST._serialized_end=367
  _LISTPROJECTSRESPONSE._serialized_start=369
  _LISTPROJECTSRESPONSE._serialized_end=448
  _GETPROJECTREQUEST._serialized_start=450
  _GETPROJECTREQUEST._serialized_end=511
  _GETPROJECTRESPONSE._serialized_start=513
  _GETPROJECTRESPONSE._serialized_end=585
  _DELETEPROJECTREQUEST._serialized_start=587
  _DELETEPROJECTREQUEST._serialized_end=629
  _DELETEPROJECTRESPONSE._serialized_start=631
  _DELETEPROJECTRESPONSE._serialized_end=668
  _UPDATEPROJECTREQUEST._serialized_start=670
  _UPDATEPROJECTREQUEST._serialized_end=793
  _UPDATEPROJECTRESPONSE._serialized_start=795
  _UPDATEPROJECTRESPONSE._serialized_end=879
  _PROJECT._serialized_start=882
  _PROJECT._serialized_end=1054
  _PROJECTSPEC._serialized_start=1057
  _PROJECTSPEC._serialized_end=1548
  _PROJECTSPEC_STATUS._serialized_start=1486
  _PROJECTSPEC_STATUS._serialized_end=1548
  _PROJECTSPECCONFIGURATION._serialized_start=1550
  _PROJECTSPECCONFIGURATION._serialized_end=1627
  _MODELREPOSITORYJFROGSETTINGS._serialized_start=1630
  _MODELREPOSITORYJFROGSETTINGS._serialized_end=1838
  _MODELREPOSITORYPULLIMAGESECRET._serialized_start=1840
  _MODELREPOSITORYPULLIMAGESECRET._serialized_end=1904
  _MODELREPOSITORYJFROGPROJECTDETAILS._serialized_start=1906
  _MODELREPOSITORYJFROGPROJECTDETAILS._serialized_end=1969
  _MODELREPOSITORYJFROGSPEC._serialized_start=1971
  _MODELREPOSITORYJFROGSPEC._serialized_end=2054
  _PROJECTSMANAGEMENTSERVICE._serialized_start=2057
  _PROJECTSMANAGEMENTSERVICE._serialized_end=2642
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.feature_store.features.deployment_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PushEnvironmentDeploymentStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_STATE_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    @property
    def deployment_state(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.features.deployment_pb2.DeploymentState]: ...
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        deployment_state: collections.abc.Iterable[qwak.feature_store.features.deployment_pb2.DeploymentState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_state", b"deployment_state", "environment_id", b"environment_id"]) -> None: ...

global___PushEnvironmentDeploymentStateRequest = PushEnvironmentDeploymentStateRequest

class PushEnvironmentDeploymentStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PushEnvironmentDeploymentStateResponse = PushEnvironmentDeploymentStateResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/workspace/workspace_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.workspace import workspace_pb2 as qwak_dot_workspace_dot_workspace__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&qwak/workspace/workspace_service.proto\x12\x19qwak.workspace.management\x1a\x1eqwak/workspace/workspace.proto\"Z\n\x16\x43reateWorkspaceRequest\x12@\n\x0eworkspace_spec\x18\x01 \x01(\x0b\x32(.qwak.workspace.management.WorkspaceSpec\"/\n\x17\x43reateWorkspaceResponse\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"p\n\x16UpdateWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12@\n\x0eworkspace_spec\x18\x02 \x01(\x0b\x32(.qwak.workspace.management.WorkspaceSpec\".\n\x16\x44\x65ployWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"\x19\n\x17\x44\x65ployWorkspaceResponse\"0\n\x18UndeployWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"\x1b\n\x19UndeployWorkspaceResponse\"\x19\n\x17UpdateWorkspaceResponse\"\x17\n\x15ListWorkspacesRequest\"R\n\x16ListWorkspacesResponse\x12\x38\n\nworkspaces\x18\x01 \x03(\x0b\x32$.qwak.workspace.management.Workspace\"/\n\x17GetWorkspaceByIdRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"S\n\x18GetWorkspaceByIdResponse\x12\x37\n\tworkspace\x18\x01 \x01(\x0b\x32$.qwak.workspace.management.Workspace\".\n\x16\x44\x65leteWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"\x19\n\x17\x44\x65leteWorkspaceResponse\"\x9a\x01\n$UpdateWorkspaceStatusFromEdgeRequest\x12r\n)update_workspace_status_from_edge_details\x18\x01 \x01(\x0b\x32?.qwak.workspace.management.UpdateWorkspaceStatusFromEdgeDetails\"\'\n%UpdateWorkspaceStatusFromEdgeResponse\"A\n\x1bRegisterWorkspaceTagRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x0c\n\x04tags\x18\x02 \x03(\t\"\x1e\n\x1cRegisterWorkspaceTagResponse\"\x1c\n\x1aListWorkspaceImagesRequest\"b\n\x1bListWorkspaceImagesResponse\x12\x43\n\x10workspace_images\x18\x01 \x03(\x0b\x32).qwak.workspace.management.WorkspaceImage\"\x18\n\x16\x43ountWorkspacesRequest\"(\n\x17\x43ountWorkspacesResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"\"\n GetDefaultWorkspaceValuesRequest\"z\n!GetDefaultWorkspaceValuesResponse\x12U\n\x19\x64\x65\x66\x61ult_workspace_details\x18\x01 \x01(\x0b\x32\x32.qwak.workspace.management.DefaultWorkspaceDetails\"B\n\x18MarkBuildAsCopiedRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\"\x1b\n\x19MarkBuildAsCopiedResponse\":\n\x10\x43opyBuildRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\"\x13\n\x11\x43opyBuildResponse2\xaa\x0e\n\x1aWorkspaceManagementService\x12x\n\x0f\x43reateWorkspace\x12\x31.qwak.workspace.management.CreateWorkspaceRequest\x1a\x32.qwak.workspace.management.CreateWorkspaceResponse\x12x\n\x0fUpdateWorkspace\x12\x31.qwak.workspace.management.UpdateWorkspaceRequest\x1a\x32.qwak.workspace.management.UpdateWorkspaceResponse\x12x\n\x0f\x44\x65ployWorkspace\x12\x31.qwak.workspace.management.DeployWorkspaceRequest\x1a\x32.qwak.workspace.management.DeployWorkspaceResponse\x12~\n\x11UndeployWorkspace\x12\x33.qwak.workspace.management.UndeployWorkspaceRequest\x1a\x34.qwak.workspace.management.UndeployWorkspaceResponse\x12u\n\x0eListWorkspaces\x12\x30.qwak.workspace.management.ListWorkspacesRequest\x1a\x31.qwak.workspace.management.ListWorkspacesResponse\x12{\n\x10GetWorkspaceById\x12\x32.qwak.workspace.management.GetWorkspaceByIdRequest\x1a\x33.qwak.workspace.management.GetWorkspaceByIdResponse\x12x\n\x0f\x44\x65leteWorkspace\x12\x31.qwak.workspace.management.DeleteWorkspaceRequest\x1a\x32.qwak.workspace.management.DeleteWorkspaceResponse\x12\xa2\x01\n\x1dUpdateWorkspaceStatusFromEdge\x12?.qwak.workspace.management.UpdateWorkspaceStatusFromEdgeRequest\x1a@.qwak.workspace.management.UpdateWorkspaceStatusFromEdgeResponse\x12\x84\x01\n\x13ListWorkspaceImages\x12\x35.qwak.workspace.management.ListWorkspaceImagesRequest\x1a\x36.qwak.workspace.management.ListWorkspaceImagesResponse\x12\x88\x01\n\x15RegisterWorkspaceTags\x12\x36.qwak.workspace.management.RegisterWorkspaceTagRequest\x1a\x37.qwak.workspace.management.RegisterWorkspaceTagResponse\x12x\n\x0f\x43ountWorkspaces\x12\x31.qwak.workspace.management.CountWorkspacesRequest\x1a\x32.qwak.workspace.management.CountWorkspacesResponse\x12\x96\x01\n\x19GetDefaultWorkspaceValues\x12;.qwak.workspace.management.GetDefaultWorkspaceValuesRequest\x1a<.qwak.workspace.management.GetDefaultWorkspaceValuesResponse\x12~\n\x11MarkBuildAsCopied\x12\x33.qwak.workspace.management.MarkBuildAsCopiedRequest\x1a\x34.qwak.workspace.management.MarkBuildAsCopiedResponse\x12\x66\n\tCopyBuild\x12+.qwak.workspace.management.CopyBuildRequest\x1a,.qwak.workspace.management.CopyBuildResponseBB\n$com.qwak.ai.management.workspace.apiP\x01Z\x18qwak/workspace;workspaceb\x06proto3')



_CREATEWORKSPACEREQUEST = DESCRIPTOR.message_types_by_name['CreateWorkspaceRequest']
_CREATEWORKSPACERESPONSE = DESCRIPTOR.message_types_by_name['CreateWorkspaceResponse']
_UPDATEWORKSPACEREQUEST = DESCRIPTOR.message_types_by_name['UpdateWorkspaceRequest']
_DEPLOYWORKSPACEREQUEST = DESCRIPTOR.message_types_by_name['DeployWorkspaceRequest']
_DEPLOYWORKSPACERESPONSE = DESCRIPTOR.message_types_by_name['DeployWorkspaceResponse']
_UNDEPLOYWORKSPACEREQUEST = DESCRIPTOR.message_types_by_name['UndeployWorkspaceRequest']
_UNDEPLOYWORKSPACERESPONSE = DESCRIPTOR.message_types_by_name['UndeployWorkspaceResponse']
_UPDATEWORKSPACERESPONSE = DESCRIPTOR.message_types_by_name['UpdateWorkspaceResponse']
_LISTWORKSPACESREQUEST = DESCRIPTOR.message_types_by_name['ListWorkspacesRequest']
_LISTWORKSPACESRESPONSE = DESCRIPTOR.message_types_by_name['ListWorkspacesResponse']
_GETWORKSPACEBYIDREQUEST = DESCRIPTOR.message_types_by_name['GetWorkspaceByIdRequest']
_GETWORKSPACEBYIDRESPONSE = DESCRIPTOR.message_types_by_name['GetWorkspaceByIdResponse']
_DELETEWORKSPACEREQUEST = DESCRIPTOR.message_types_by_name['DeleteWorkspaceRequest']
_DELETEWORKSPACERESPONSE = DESCRIPTOR.message_types_by_name['DeleteWorkspaceResponse']
_UPDATEWORKSPACESTATUSFROMEDGEREQUEST = DESCRIPTOR.message_types_by_name['UpdateWorkspaceStatusFromEdgeRequest']
_UPDATEWORKSPACESTATUSFROMEDGERESPONSE = DESCRIPTOR.message_types_by_name['UpdateWorkspaceStatusFromEdgeResponse']
_REGISTERWORKSPACETAGREQUEST = DESCRIPTOR.message_types_by_name['RegisterWorkspaceTagRequest']
_REGISTERWORKSPACETAGRESPONSE = DESCRIPTOR.message_types_by_name['RegisterWorkspaceTagResponse']
_LISTWORKSPACEIMAGESREQUEST = DESCRIPTOR.message_types_by_name['ListWorkspaceImagesRequest']
_LISTWORKSPACEIMAGESRESPONSE = DESCRIPTOR.message_types_by_name['ListWorkspaceImagesResponse']
_COUNTWORKSPACESREQUEST = DESCRIPTOR.message_types_by_name['CountWorkspacesRequest']
_COUNTWORKSPACESRESPONSE = DESCRIPTOR.message_types_by_name['CountWorkspacesResponse']
_GETDEFAULTWORKSPACEVALUESREQUEST = DESCRIPTOR.message_types_by_name['GetDefaultWorkspaceValuesRequest']
_GETDEFAULTWORKSPACEVALUESRESPONSE = DESCRIPTOR.message_types_by_name['GetDefaultWorkspaceValuesResponse']
_MARKBUILDASCOPIEDREQUEST = DESCRIPTOR.message_types_by_name['MarkBuildAsCopiedRequest']
_MARKBUILDASCOPIEDRESPONSE = DESCRIPTOR.message_types_by_name['MarkBuildAsCopiedResponse']
_COPYBUILDREQUEST = DESCRIPTOR.message_types_by_name['CopyBuildRequest']
_COPYBUILDRESPONSE = DESCRIPTOR.message_types_by_name['CopyBuildResponse']
CreateWorkspaceRequest = _reflection.GeneratedProtocolMessageType('CreateWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWORKSPACEREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.CreateWorkspaceRequest)
  })
_sym_db.RegisterMessage(CreateWorkspaceRequest)

CreateWorkspaceResponse = _reflection.GeneratedProtocolMessageType('CreateWorkspaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWORKSPACERESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.CreateWorkspaceResponse)
  })
_sym_db.RegisterMessage(CreateWorkspaceResponse)

UpdateWorkspaceRequest = _reflection.GeneratedProtocolMessageType('UpdateWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWORKSPACEREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.UpdateWorkspaceRequest)
  })
_sym_db.RegisterMessage(UpdateWorkspaceRequest)

DeployWorkspaceRequest = _reflection.GeneratedProtocolMessageType('DeployWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYWORKSPACEREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.DeployWorkspaceRequest)
  })
_sym_db.RegisterMessage(DeployWorkspaceRequest)

DeployWorkspaceResponse = _reflection.GeneratedProtocolMessageType('DeployWorkspaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYWORKSPACERESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.DeployWorkspaceResponse)
  })
_sym_db.RegisterMessage(DeployWorkspaceResponse)

UndeployWorkspaceRequest = _reflection.GeneratedProtocolMessageType('UndeployWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNDEPLOYWORKSPACEREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.UndeployWorkspaceRequest)
  })
_sym_db.RegisterMessage(UndeployWorkspaceRequest)

UndeployWorkspaceResponse = _reflection.GeneratedProtocolMessageType('UndeployWorkspaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _UNDEPLOYWORKSPACERESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.UndeployWorkspaceResponse)
  })
_sym_db.RegisterMessage(UndeployWorkspaceResponse)

UpdateWorkspaceResponse = _reflection.GeneratedProtocolMessageType('UpdateWorkspaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWORKSPACERESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.UpdateWorkspaceResponse)
  })
_sym_db.RegisterMessage(UpdateWorkspaceResponse)

ListWorkspacesRequest = _reflection.GeneratedProtocolMessageType('ListWorkspacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKSPACESREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.ListWorkspacesRequest)
  })
_sym_db.RegisterMessage(ListWorkspacesRequest)

ListWorkspacesResponse = _reflection.GeneratedProtocolMessageType('ListWorkspacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKSPACESRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.ListWorkspacesResponse)
  })
_sym_db.RegisterMessage(ListWorkspacesResponse)

GetWorkspaceByIdRequest = _reflection.GeneratedProtocolMessageType('GetWorkspaceByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKSPACEBYIDREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.GetWorkspaceByIdRequest)
  })
_sym_db.RegisterMessage(GetWorkspaceByIdRequest)

GetWorkspaceByIdResponse = _reflection.GeneratedProtocolMessageType('GetWorkspaceByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKSPACEBYIDRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.GetWorkspaceByIdResponse)
  })
_sym_db.RegisterMessage(GetWorkspaceByIdResponse)

DeleteWorkspaceRequest = _reflection.GeneratedProtocolMessageType('DeleteWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWORKSPACEREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.DeleteWorkspaceRequest)
  })
_sym_db.RegisterMessage(DeleteWorkspaceRequest)

DeleteWorkspaceResponse = _reflection.GeneratedProtocolMessageType('DeleteWorkspaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWORKSPACERESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.DeleteWorkspaceResponse)
  })
_sym_db.RegisterMessage(DeleteWorkspaceResponse)

UpdateWorkspaceStatusFromEdgeRequest = _reflection.GeneratedProtocolMessageType('UpdateWorkspaceStatusFromEdgeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWORKSPACESTATUSFROMEDGEREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.UpdateWorkspaceStatusFromEdgeRequest)
  })
_sym_db.RegisterMessage(UpdateWorkspaceStatusFromEdgeRequest)

UpdateWorkspaceStatusFromEdgeResponse = _reflection.GeneratedProtocolMessageType('UpdateWorkspaceStatusFromEdgeResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWORKSPACESTATUSFROMEDGERESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.UpdateWorkspaceStatusFromEdgeResponse)
  })
_sym_db.RegisterMessage(UpdateWorkspaceStatusFromEdgeResponse)

RegisterWorkspaceTagRequest = _reflection.GeneratedProtocolMessageType('RegisterWorkspaceTagRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERWORKSPACETAGREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.RegisterWorkspaceTagRequest)
  })
_sym_db.RegisterMessage(RegisterWorkspaceTagRequest)

RegisterWorkspaceTagResponse = _reflection.GeneratedProtocolMessageType('RegisterWorkspaceTagResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERWORKSPACETAGRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.RegisterWorkspaceTagResponse)
  })
_sym_db.RegisterMessage(RegisterWorkspaceTagResponse)

ListWorkspaceImagesRequest = _reflection.GeneratedProtocolMessageType('ListWorkspaceImagesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKSPACEIMAGESREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.ListWorkspaceImagesRequest)
  })
_sym_db.RegisterMessage(ListWorkspaceImagesRequest)

ListWorkspaceImagesResponse = _reflection.GeneratedProtocolMessageType('ListWorkspaceImagesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKSPACEIMAGESRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.ListWorkspaceImagesResponse)
  })
_sym_db.RegisterMessage(ListWorkspaceImagesResponse)

CountWorkspacesRequest = _reflection.GeneratedProtocolMessageType('CountWorkspacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _COUNTWORKSPACESREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.CountWorkspacesRequest)
  })
_sym_db.RegisterMessage(CountWorkspacesRequest)

CountWorkspacesResponse = _reflection.GeneratedProtocolMessageType('CountWorkspacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _COUNTWORKSPACESRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.CountWorkspacesResponse)
  })
_sym_db.RegisterMessage(CountWorkspacesResponse)

GetDefaultWorkspaceValuesRequest = _reflection.GeneratedProtocolMessageType('GetDefaultWorkspaceValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDEFAULTWORKSPACEVALUESREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.GetDefaultWorkspaceValuesRequest)
  })
_sym_db.RegisterMessage(GetDefaultWorkspaceValuesRequest)

GetDefaultWorkspaceValuesResponse = _reflection.GeneratedProtocolMessageType('GetDefaultWorkspaceValuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDEFAULTWORKSPACEVALUESRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.GetDefaultWorkspaceValuesResponse)
  })
_sym_db.RegisterMessage(GetDefaultWorkspaceValuesResponse)

MarkBuildAsCopiedRequest = _reflection.GeneratedProtocolMessageType('MarkBuildAsCopiedRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKBUILDASCOPIEDREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.MarkBuildAsCopiedRequest)
  })
_sym_db.RegisterMessage(MarkBuildAsCopiedRequest)

MarkBuildAsCopiedResponse = _reflection.GeneratedProtocolMessageType('MarkBuildAsCopiedResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKBUILDASCOPIEDRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.MarkBuildAsCopiedResponse)
  })
_sym_db.RegisterMessage(MarkBuildAsCopiedResponse)

CopyBuildRequest = _reflection.GeneratedProtocolMessageType('CopyBuildRequest', (_message.Message,), {
  'DESCRIPTOR' : _COPYBUILDREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.CopyBuildRequest)
  })
_sym_db.RegisterMessage(CopyBuildRequest)

CopyBuildResponse = _reflection.GeneratedProtocolMessageType('CopyBuildResponse', (_message.Message,), {
  'DESCRIPTOR' : _COPYBUILDRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.CopyBuildResponse)
  })
_sym_db.RegisterMessage(CopyBuildResponse)

_WORKSPACEMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['WorkspaceManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.qwak.ai.management.workspace.apiP\001Z\030qwak/workspace;workspace'
  _CREATEWORKSPACEREQUEST._serialized_start=101
  _CREATEWORKSPACEREQUEST._serialized_end=191
  _CREATEWORKSPACERESPONSE._serialized_start=193
  _CREATEWORKSPACERESPONSE._serialized_end=240
  _UPDATEWORKSPACEREQUEST._serialized_start=242
  _UPDATEWORKSPACEREQUEST._serialized_end=354
  _DEPLOYWORKSPACEREQUEST._serialized_start=356
  _DEPLOYWORKSPACEREQUEST._serialized_end=402
  _DEPLOYWORKSPACERESPONSE._serialized_start=404
  _DEPLOYWORKSPACERESPONSE._serialized_end=429
  _UNDEPLOYWORKSPACEREQUEST._serialized_start=431
  _UNDEPLOYWORKSPACEREQUEST._serialized_end=479
  _UNDEPLOYWORKSPACERESPONSE._serialized_start=481
  _UNDEPLOYWORKSPACERESPONSE._serialized_end=508
  _UPDATEWORKSPACERESPONSE._serialized_start=510
  _UPDATEWORKSPACERESPONSE._serialized_end=535
  _LISTWORKSPACESREQUEST._serialized_start=537
  _LISTWORKSPACESREQUEST._serialized_end=560
  _LISTWORKSPACESRESPONSE._serialized_start=562
  _LISTWORKSPACESRESPONSE._serialized_end=644
  _GETWORKSPACEBYIDREQUEST._serialized_start=646
  _GETWORKSPACEBYIDREQUEST._serialized_end=693
  _GETWORKSPACEBYIDRESPONSE._serialized_start=695
  _GETWORKSPACEBYIDRESPONSE._serialized_end=778
  _DELETEWORKSPACEREQUEST._serialized_start=780
  _DELETEWORKSPACEREQUEST._serialized_end=826
  _DELETEWORKSPACERESPONSE._serialized_start=828
  _DELETEWORKSPACERESPONSE._serialized_end=853
  _UPDATEWORKSPACESTATUSFROMEDGEREQUEST._serialized_start=856
  _UPDATEWORKSPACESTATUSFROMEDGEREQUEST._serialized_end=1010
  _UPDATEWORKSPACESTATUSFROMEDGERESPONSE._serialized_start=1012
  _UPDATEWORKSPACESTATUSFROMEDGERESPONSE._serialized_end=1051
  _REGISTERWORKSPACETAGREQUEST._serialized_start=1053
  _REGISTERWORKSPACETAGREQUEST._serialized_end=1118
  _REGISTERWORKSPACETAGRESPONSE._serialized_start=1120
  _REGISTERWORKSPACETAGRESPONSE._serialized_end=1150
  _LISTWORKSPACEIMAGESREQUEST._serialized_start=1152
  _LISTWORKSPACEIMAGESREQUEST._serialized_end=1180
  _LISTWORKSPACEIMAGESRESPONSE._serialized_start=1182
  _LISTWORKSPACEIMAGESRESPONSE._serialized_end=1280
  _COUNTWORKSPACESREQUEST._serialized_start=1282
  _COUNTWORKSPACESREQUEST._serialized_end=1306
  _COUNTWORKSPACESRESPONSE._serialized_start=1308
  _COUNTWORKSPACESRESPONSE._serialized_end=1348
  _GETDEFAULTWORKSPACEVALUESREQUEST._serialized_start=1350
  _GETDEFAULTWORKSPACEVALUESREQUEST._serialized_end=1384
  _GETDEFAULTWORKSPACEVALUESRESPONSE._serialized_start=1386
  _GETDEFAULTWORKSPACEVALUESRESPONSE._serialized_end=1508
  _MARKBUILDASCOPIEDREQUEST._serialized_start=1510
  _MARKBUILDASCOPIEDREQUEST._serialized_end=1576
  _MARKBUILDASCOPIEDRESPONSE._serialized_start=1578
  _MARKBUILDASCOPIEDRESPONSE._serialized_end=1605
  _COPYBUILDREQUEST._serialized_start=1607
  _COPYBUILDREQUEST._serialized_end=1665
  _COPYBUILDRESPONSE._serialized_start=1667
  _COPYBUILDRESPONSE._serialized_end=1686
  _WORKSPACEMANAGEMENTSERVICE._serialized_start=1689
  _WORKSPACEMANAGEMENTSERVICE._serialized_end=3523
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.integration.integration_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateIntegrationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_SPEC_FIELD_NUMBER: builtins.int
    @property
    def integration_spec(self) -> qwak.integration.integration_pb2.IntegrationSpec:
        """The integration spec to add"""
    def __init__(
        self,
        *,
        integration_spec: qwak.integration.integration_pb2.IntegrationSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["integration_spec", b"integration_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration_spec", b"integration_spec"]) -> None: ...

global___CreateIntegrationRequest = CreateIntegrationRequest

class CreateIntegrationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    IS_SUCCESSFUL_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    integration_id: builtins.str
    """The id of the created integration"""
    is_successful: builtins.bool
    """Is The creation successful"""
    error_message: builtins.str
    """The reason the integration failed"""
    def __init__(
        self,
        *,
        integration_id: builtins.str = ...,
        is_successful: builtins.bool = ...,
        error_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_message", b"error_message", "integration_id", b"integration_id", "is_successful", b"is_successful"]) -> None: ...

global___CreateIntegrationResponse = CreateIntegrationResponse

class GetIntegrationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    integration_id: builtins.str
    """Integration Id to get"""
    def __init__(
        self,
        *,
        integration_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration_id", b"integration_id"]) -> None: ...

global___GetIntegrationRequest = GetIntegrationRequest

class GetIntegrationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_FIELD_NUMBER: builtins.int
    @property
    def integration(self) -> qwak.integration.integration_pb2.Integration:
        """integration"""
    def __init__(
        self,
        *,
        integration: qwak.integration.integration_pb2.Integration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["integration", b"integration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration", b"integration"]) -> None: ...

global___GetIntegrationResponse = GetIntegrationResponse

class ListIntegrationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListIntegrationRequest = ListIntegrationRequest

class ListIntegrationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATIONS_FIELD_NUMBER: builtins.int
    @property
    def integrations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.integration.integration_pb2.Integration]:
        """list of integration"""
    def __init__(
        self,
        *,
        integrations: collections.abc.Iterable[qwak.integration.integration_pb2.Integration] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["integrations", b"integrations"]) -> None: ...

global___ListIntegrationsResponse = ListIntegrationsResponse

class UpdateIntegrationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    INTEGRATION_SPEC_FIELD_NUMBER: builtins.int
    integration_id: builtins.str
    """Integration Id to update"""
    @property
    def integration_spec(self) -> qwak.integration.integration_pb2.IntegrationSpec:
        """The updated spec"""
    def __init__(
        self,
        *,
        integration_id: builtins.str = ...,
        integration_spec: qwak.integration.integration_pb2.IntegrationSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["integration_spec", b"integration_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration_id", b"integration_id", "integration_spec", b"integration_spec"]) -> None: ...

global___UpdateIntegrationRequest = UpdateIntegrationRequest

class UpdateIntegrationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateIntegrationResponse = UpdateIntegrationResponse

class DeleteIntegrationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    integration_id: builtins.str
    """Integration Id to delete"""
    def __init__(
        self,
        *,
        integration_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration_id", b"integration_id"]) -> None: ...

global___DeleteIntegrationRequest = DeleteIntegrationRequest

class DeleteIntegrationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteIntegrationResponse = DeleteIntegrationResponse

class ValidateIntegrationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATION_SPEC_FIELD_NUMBER: builtins.int
    @property
    def validation_spec(self) -> qwak.integration.integration_pb2.IntegrationValidationSpec: ...
    def __init__(
        self,
        *,
        validation_spec: qwak.integration.integration_pb2.IntegrationValidationSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["validation_spec", b"validation_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["validation_spec", b"validation_spec"]) -> None: ...

global___ValidateIntegrationRequest = ValidateIntegrationRequest

class ValidateIntegrationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> qwak.integration.integration_pb2.ValidationIntegrationResult:
        """The validation result"""
    def __init__(
        self,
        *,
        result: qwak.integration.integration_pb2.ValidationIntegrationResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result"]) -> None: ...

global___ValidateIntegrationResponse = ValidateIntegrationResponse

class GetIntegrationOptionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    integration_id: builtins.str
    """The integration to get options for"""
    def __init__(
        self,
        *,
        integration_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration_id", b"integration_id"]) -> None: ...

global___GetIntegrationOptionsRequest = GetIntegrationOptionsRequest

class GetIntegrationOptionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> qwak.integration.integration_pb2.IntegrationOptions:
        """The integration options"""
    def __init__(
        self,
        *,
        options: qwak.integration.integration_pb2.IntegrationOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___GetIntegrationOptionsResponse = GetIntegrationOptionsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/serving/management.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.serving import metadata_pb2 as qwak_dot_feature__store_dot_serving_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/feature_store/serving/management.proto\x12%com.qwak.ai.feature.store.serving.api\x1a)qwak/feature_store/serving/metadata.proto\"<\n#GetFeaturesetMemoryUsageByIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"}\n$GetFeaturesetMemoryUsageByIdResponse\x12U\n\x05usage\x18\x01 \x01(\x0b\x32\x46.com.qwak.ai.feature.store.serving.metadata.FeaturesetMemoryUsageStats\".\n,GetFeaturesetMemoryUsageByEnvironmentRequest\"\x8c\x01\n-GetFeaturesetMemoryUsageByEnvironmentResponse\x12[\n\x0busage_stats\x18\x01 \x03(\x0b\x32\x46.com.qwak.ai.feature.store.serving.metadata.FeaturesetMemoryUsageStats2\xac\x03\n\x1b\x46\x65\x61turesetManagementService\x12\xb7\x01\n\x1cGetFeaturesetMemoryUsageById\x12J.com.qwak.ai.feature.store.serving.api.GetFeaturesetMemoryUsageByIdRequest\x1aK.com.qwak.ai.feature.store.serving.api.GetFeaturesetMemoryUsageByIdResponse\x12\xd2\x01\n%GetFeaturesetMemoryUsageByEnvironment\x12S.com.qwak.ai.feature.store.serving.api.GetFeaturesetMemoryUsageByEnvironmentRequest\x1aT.com.qwak.ai.feature.store.serving.api.GetFeaturesetMemoryUsageByEnvironmentResponseB\'\n%com.qwak.ai.feature.store.serving.apib\x06proto3')



_GETFEATURESETMEMORYUSAGEBYIDREQUEST = DESCRIPTOR.message_types_by_name['GetFeaturesetMemoryUsageByIdRequest']
_GETFEATURESETMEMORYUSAGEBYIDRESPONSE = DESCRIPTOR.message_types_by_name['GetFeaturesetMemoryUsageByIdResponse']
_GETFEATURESETMEMORYUSAGEBYENVIRONMENTREQUEST = DESCRIPTOR.message_types_by_name['GetFeaturesetMemoryUsageByEnvironmentRequest']
_GETFEATURESETMEMORYUSAGEBYENVIRONMENTRESPONSE = DESCRIPTOR.message_types_by_name['GetFeaturesetMemoryUsageByEnvironmentResponse']
GetFeaturesetMemoryUsageByIdRequest = _reflection.GeneratedProtocolMessageType('GetFeaturesetMemoryUsageByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETMEMORYUSAGEBYIDREQUEST,
  '__module__' : 'qwak.feature_store.serving.management_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.ai.feature.store.serving.api.GetFeaturesetMemoryUsageByIdRequest)
  })
_sym_db.RegisterMessage(GetFeaturesetMemoryUsageByIdRequest)

GetFeaturesetMemoryUsageByIdResponse = _reflection.GeneratedProtocolMessageType('GetFeaturesetMemoryUsageByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETMEMORYUSAGEBYIDRESPONSE,
  '__module__' : 'qwak.feature_store.serving.management_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.ai.feature.store.serving.api.GetFeaturesetMemoryUsageByIdResponse)
  })
_sym_db.RegisterMessage(GetFeaturesetMemoryUsageByIdResponse)

GetFeaturesetMemoryUsageByEnvironmentRequest = _reflection.GeneratedProtocolMessageType('GetFeaturesetMemoryUsageByEnvironmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETMEMORYUSAGEBYENVIRONMENTREQUEST,
  '__module__' : 'qwak.feature_store.serving.management_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.ai.feature.store.serving.api.GetFeaturesetMemoryUsageByEnvironmentRequest)
  })
_sym_db.RegisterMessage(GetFeaturesetMemoryUsageByEnvironmentRequest)

GetFeaturesetMemoryUsageByEnvironmentResponse = _reflection.GeneratedProtocolMessageType('GetFeaturesetMemoryUsageByEnvironmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETMEMORYUSAGEBYENVIRONMENTRESPONSE,
  '__module__' : 'qwak.feature_store.serving.management_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.ai.feature.store.serving.api.GetFeaturesetMemoryUsageByEnvironmentResponse)
  })
_sym_db.RegisterMessage(GetFeaturesetMemoryUsageByEnvironmentResponse)

_FEATURESETMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['FeaturesetManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.serving.api'
  _GETFEATURESETMEMORYUSAGEBYIDREQUEST._serialized_start=129
  _GETFEATURESETMEMORYUSAGEBYIDREQUEST._serialized_end=189
  _GETFEATURESETMEMORYUSAGEBYIDRESPONSE._serialized_start=191
  _GETFEATURESETMEMORYUSAGEBYIDRESPONSE._serialized_end=316
  _GETFEATURESETMEMORYUSAGEBYENVIRONMENTREQUEST._serialized_start=318
  _GETFEATURESETMEMORYUSAGEBYENVIRONMENTREQUEST._serialized_end=364
  _GETFEATURESETMEMORYUSAGEBYENVIRONMENTRESPONSE._serialized_start=367
  _GETFEATURESETMEMORYUSAGEBYENVIRONMENTRESPONSE._serialized_end=507
  _FEATURESETMANAGEMENTSERVICE._serialized_start=510
  _FEATURESETMANAGEMENTSERVICE._serialized_end=938
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/self_service/account/v0/account_status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1qwak/self_service/account/v0/account_status.proto\x12\x1cqwak.self_service.account.v0\"\xbf\x01\n\rAccountStatus\x12_\n\x1c\x61\x63\x63ount_creation_in_progress\x18\x01 \x01(\x0b\x32\x37.qwak.self_service.account.v0.AccountCreationInProgressH\x00\x12\x43\n\raccount_ready\x18\x02 \x01(\x0b\x32*.qwak.self_service.account.v0.AccountReadyH\x00\x42\x08\n\x06status\"\x1b\n\x19\x41\x63\x63ountCreationInProgress\"\"\n\x0c\x41\x63\x63ountReady\x12\x12\n\naccount_id\x18\x01 \x01(\tB\xb9\x01\n#com.qwak.ai.self_service.account.v0P\x01Z\x8f\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0b\x06proto3')



_ACCOUNTSTATUS = DESCRIPTOR.message_types_by_name['AccountStatus']
_ACCOUNTCREATIONINPROGRESS = DESCRIPTOR.message_types_by_name['AccountCreationInProgress']
_ACCOUNTREADY = DESCRIPTOR.message_types_by_name['AccountReady']
AccountStatus = _reflection.GeneratedProtocolMessageType('AccountStatus', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTSTATUS,
  '__module__' : 'qwak.self_service.account.v0.account_status_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.AccountStatus)
  })
_sym_db.RegisterMessage(AccountStatus)

AccountCreationInProgress = _reflection.GeneratedProtocolMessageType('AccountCreationInProgress', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTCREATIONINPROGRESS,
  '__module__' : 'qwak.self_service.account.v0.account_status_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.AccountCreationInProgress)
  })
_sym_db.RegisterMessage(AccountCreationInProgress)

AccountReady = _reflection.GeneratedProtocolMessageType('AccountReady', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTREADY,
  '__module__' : 'qwak.self_service.account.v0.account_status_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.AccountReady)
  })
_sym_db.RegisterMessage(AccountReady)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.self_service.account.v0P\001Z\217\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0'
  _ACCOUNTSTATUS._serialized_start=84
  _ACCOUNTSTATUS._serialized_end=275
  _ACCOUNTCREATIONINPROGRESS._serialized_start=277
  _ACCOUNTCREATIONINPROGRESS._serialized_end=304
  _ACCOUNTREADY._serialized_start=306
  _ACCOUNTREADY._serialized_end=340
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.automation.v1 import automation_management_service_pb2 as qwak_dot_automation_dot_v1_dot_automation__management__service__pb2


class AutomationManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateAutomation = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/CreateAutomation',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.CreateAutomationRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.CreateAutomationResponse.FromString,
                )
        self.UpdateAutomation = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/UpdateAutomation',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationResponse.FromString,
                )
        self.DeleteAutomation = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/DeleteAutomation',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.DeleteAutomationRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.DeleteAutomationResponse.FromString,
                )
        self.GetAutomation = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/GetAutomation',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationResponse.FromString,
                )
        self.GetAutomationByName = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/GetAutomationByName',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationByNameRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationByNameResponse.FromString,
                )
        self.ListAutomations = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/ListAutomations',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationsRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationsResponse.FromString,
                )
        self.ListAutomationExecutions = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/ListAutomationExecutions',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationExecutionsRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationExecutionsResponse.FromString,
                )
        self.ListLastAutomationExecutions = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/ListLastAutomationExecutions',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListLastAutomationExecutionsRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListLastAutomationExecutionsResponse.FromString,
                )
        self.RegisterAutomationExecution = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/RegisterAutomationExecution',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RegisterAutomationExecutionRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RegisterAutomationExecutionResponse.FromString,
                )
        self.UpdateAutomationExecution = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/UpdateAutomationExecution',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationExecutionRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationExecutionResponse.FromString,
                )
        self.ToggleAutomationActivity = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/ToggleAutomationActivity',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ToggleAutomationActivityRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ToggleAutomationActivityResponse.FromString,
                )
        self.RunAutomation = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/RunAutomation',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RunAutomationRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RunAutomationResponse.FromString,
                )


class AutomationManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateAutomation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAutomation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAutomation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAutomation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAutomationByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAutomations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAutomationExecutions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLastAutomationExecutions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterAutomationExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAutomationExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ToggleAutomationActivity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunAutomation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AutomationManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateAutomation': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAutomation,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.CreateAutomationRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.CreateAutomationResponse.SerializeToString,
            ),
            'UpdateAutomation': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAutomation,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationResponse.SerializeToString,
            ),
            'DeleteAutomation': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAutomation,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.DeleteAutomationRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.DeleteAutomationResponse.SerializeToString,
            ),
            'GetAutomation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAutomation,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationResponse.SerializeToString,
            ),
            'GetAutomationByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAutomationByName,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationByNameRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationByNameResponse.SerializeToString,
            ),
            'ListAutomations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAutomations,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationsRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationsResponse.SerializeToString,
            ),
            'ListAutomationExecutions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAutomationExecutions,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationExecutionsRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationExecutionsResponse.SerializeToString,
            ),
            'ListLastAutomationExecutions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLastAutomationExecutions,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListLastAutomationExecutionsRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListLastAutomationExecutionsResponse.SerializeToString,
            ),
            'RegisterAutomationExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterAutomationExecution,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RegisterAutomationExecutionRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RegisterAutomationExecutionResponse.SerializeToString,
            ),
            'UpdateAutomationExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAutomationExecution,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationExecutionRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationExecutionResponse.SerializeToString,
            ),
            'ToggleAutomationActivity': grpc.unary_unary_rpc_method_handler(
                    servicer.ToggleAutomationActivity,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ToggleAutomationActivityRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ToggleAutomationActivityResponse.SerializeToString,
            ),
            'RunAutomation': grpc.unary_unary_rpc_method_handler(
                    servicer.RunAutomation,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RunAutomationRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RunAutomationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.automation.v1.AutomationManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AutomationManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateAutomation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/CreateAutomation',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.CreateAutomationRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.CreateAutomationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAutomation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/UpdateAutomation',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAutomation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/DeleteAutomation',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.DeleteAutomationRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.DeleteAutomationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAutomation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/GetAutomation',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAutomationByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/GetAutomationByName',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationByNameRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAutomations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/ListAutomations',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationsRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAutomationExecutions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/ListAutomationExecutions',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationExecutionsRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationExecutionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLastAutomationExecutions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/ListLastAutomationExecutions',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListLastAutomationExecutionsRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListLastAutomationExecutionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterAutomationExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/RegisterAutomationExecution',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RegisterAutomationExecutionRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RegisterAutomationExecutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAutomationExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/UpdateAutomationExecution',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationExecutionRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationExecutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ToggleAutomationActivity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/ToggleAutomationActivity',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ToggleAutomationActivityRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ToggleAutomationActivityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunAutomation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/RunAutomation',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RunAutomationRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RunAutomationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import time
import uuid

import pandas as pd
from _qwak_proto.qwak.ecosystem.v0.ecosystem_runtime_service_pb2 import (
    GetCloudCredentialsParameters,
    GetCloudCredentialsRequest,
    OfflineFeatureStoreClient,
    PermissionSet,
)
from google.protobuf.duration_pb2 import Duration
from qwak.clients.administration.eco_system.client import EcosystemClient
from qwak.exceptions import QwakException
from qwak.feature_store.offline._query_engine import BaseQueryEngine

RECONNECT_THRESHOLD_SEC = 300


class AthenaQueryEngine(BaseQueryEngine):
    def __init__(self):
        eco_client = EcosystemClient()
        self.bucket, environment_id = self._get_env_details(eco_client)

        self.staging_folder_prefix = (
            f"{environment_id}/tmp/offline_fs/{str(uuid.uuid4())}"  # nosec B108
        )
        self.temp_join_table_base_folder = (
            f"s3://{self.bucket}/{self.staging_folder_prefix}"
        )

        self.conn, self.expiration_time = self._init_connection()
        self.cursor = self.conn.cursor()

        self.join_table_specs = []

        self.join_tables_db_name = f"qwak_temp_data_{environment_id.replace('-', '_')}"
        self.cursor.execute(f"CREATE DATABASE IF NOT EXISTS {self.join_tables_db_name}")

    @staticmethod
    def _get_env_details(eco_client):
        environment_configuration = eco_client.get_environment_configuration()

        return (
            environment_configuration.configuration.object_storage_bucket,
            environment_configuration.id,
        )

    def _init_connection(self):
        try:
            # obtain credentials through STS
            eco_client = EcosystemClient()
            cloud_credentials_response = eco_client.get_cloud_credentials(
                request=GetCloudCredentialsRequest(
                    parameters=GetCloudCredentialsParameters(
                        duration=Duration(seconds=60 * 60, nanos=0),
                        permission_set=PermissionSet(
                            offline_feature_store_client=OfflineFeatureStoreClient()
                        ),
                    )
                )
            )

            aws_credentials = (
                cloud_credentials_response.cloud_credentials.aws_temporary_credentials
            )

            try:
                from pyathena import connect
                from pyathena.pandas.cursor import PandasCursor
            except ImportError:
                raise QwakException(
                    """
                    Missing 'pyathena' dependency required for fetching data from the offline store.
                    Please pip install pyathena
                """
                )

            conn = connect(
                s3_staging_dir=self.temp_join_table_base_folder,
                aws_access_key_id=aws_credentials.access_key_id,
                aws_secret_access_key=aws_credentials.secret_access_key,
                aws_session_token=aws_credentials.session_token,
                region_name=aws_credentials.region,
                cursor_class=PandasCursor,
            )

            return (
                conn,
                aws_credentials.expiration_time.seconds,
            )

        except QwakException as e:
            raise e

        except Exception as e:
            raise QwakException(
                f"Got an error trying to retrieve credentials to query the offline store "
                f"in the cloud, error is: {e}"
            )

    def upload_table(self, df: pd.DataFrame):
        join_table_spec = super().JoinTableSpec(
            self.join_tables_db_name, AthenaQueryEngine.get_quotes()
        )
        self.join_table_specs.append(join_table_spec)

        from pyathena.pandas.util import to_sql

        to_sql(
            df,
            join_table_spec.table_name,
            self.conn,
            f"{self.temp_join_table_base_folder}/{join_table_spec.table_name}/",
            schema=self.join_tables_db_name,
            index=False,
            if_exists="replace",
        )

        return join_table_spec.join_table_full_path

    def run_query(self, query: str):
        self._check_reconnection()
        return self.cursor.execute(query).fetchall()

    def read_pandas_from_query(self, query: str, parse_dates=None):
        self._check_reconnection()
        return pd.read_sql(
            query,
            self.conn,
            parse_dates=parse_dates,
        )

    def _check_reconnection(self):
        if self.expiration_time - time.time() < RECONNECT_THRESHOLD_SEC:
            self.conn, self.expiration_time = self._init_connection()
            self.cursor = self.conn.cursor()

    def cleanup(self):
        self._check_reconnection()
        for join_table_spec in self.join_table_specs:
            self.cursor.execute(
                f"""DROP TABLE {join_table_spec.join_table_full_path.replace('"', '`')}"""
            )

        self.join_table_specs = []

        s3 = self.conn.session.resource("s3")
        bucket = s3.Bucket(self.bucket)
        bucket.objects.filter(Prefix=self.staging_folder_prefix).delete()

    @staticmethod
    def get_quotes():
        return '"'



from qwak.automations.automations import (
    Action,
    Automation,
    AutomationAudit,
    CustomWebhook,
    Metric,
    MetricBasedTrigger,
    NoneTrigger,
    Notification,
    ScheduledTrigger,
    SlackNotification,
    SqlMetric,
    ThresholdDirection,
    Trigger,
)
from qwak.automations.batch_execution_action import (
    BatchExecution,
    BatchJobDataSpecifications,
    BatchJobExecutionSpecifications,
)
from qwak.automations.build_and_deploy_action import (
    AggregationType,
    AutoScaleQuerySpec,
    AutoScaleTrigger,
    AutoScalingConfig,
    AutoScalingPrometheusTrigger,
    BuildMetric,
    BuildSpecifications,
    CpuResources,
    DeploymentCondition,
    DeploymentSpecifications,
    GpuResources,
    MetricType,
    QwakBuildDeploy,
    Resources,
    ClientResources,
)

__all__ = [
    "Action",
    "AggregationType",
    "Automation",
    "AutomationAudit",
    "AutoScaleQuerySpec",
    "AutoScaleTrigger",
    "AutoScalingConfig",
    "AutoScalingPrometheusTrigger",
    "BuildMetric",
    "BuildSpecifications",
    "CpuResources",
    "CustomWebhook",
    "DeploymentCondition",
    "DeploymentSpecifications",
    "GpuResources",
    "Metric",
    "MetricBasedTrigger",
    "MetricType",
    "NoneTrigger",
    "Notification",
    "QwakBuildDeploy",
    "Resources",
    "ScheduledTrigger",
    "SlackNotification",
    "SqlMetric",
    "ThresholdDirection",
    "Trigger",
    "BatchExecution",
    "BatchJobDataSpecifications",
    "BatchJobExecutionSpecifications",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/account/v1/jfrog_tenant_details.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9qwak/administration/account/v1/jfrog_tenant_details.proto\x12\x1eqwak.administration.account.v1\"\x83\x01\n\x12JfrogTenantDetails\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12Z\n\x1d\x64\x65\x66\x61ult_jfrog_project_details\x18\x02 \x01(\x0b\x32\x33.qwak.administration.account.v1.JfrogProjectDetails\"*\n\x13JfrogProjectDetails\x12\x13\n\x0bproject_key\x18\x01 \x01(\t\"t\n\x0fJfrogTenantSpec\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12N\n\x14\x64\x65\x66\x61ult_project_spec\x18\x02 \x01(\x0b\x32\x30.qwak.administration.account.v1.JfrogProjectSpec\"\'\n\x10JfrogProjectSpec\x12\x13\n\x0bproject_key\x18\x01 \x01(\tB\xb4\x01\n)com.qwak.ai.administration.api.account.v1P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0b\x06proto3')



_JFROGTENANTDETAILS = DESCRIPTOR.message_types_by_name['JfrogTenantDetails']
_JFROGPROJECTDETAILS = DESCRIPTOR.message_types_by_name['JfrogProjectDetails']
_JFROGTENANTSPEC = DESCRIPTOR.message_types_by_name['JfrogTenantSpec']
_JFROGPROJECTSPEC = DESCRIPTOR.message_types_by_name['JfrogProjectSpec']
JfrogTenantDetails = _reflection.GeneratedProtocolMessageType('JfrogTenantDetails', (_message.Message,), {
  'DESCRIPTOR' : _JFROGTENANTDETAILS,
  '__module__' : 'qwak.administration.account.v1.jfrog_tenant_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.JfrogTenantDetails)
  })
_sym_db.RegisterMessage(JfrogTenantDetails)

JfrogProjectDetails = _reflection.GeneratedProtocolMessageType('JfrogProjectDetails', (_message.Message,), {
  'DESCRIPTOR' : _JFROGPROJECTDETAILS,
  '__module__' : 'qwak.administration.account.v1.jfrog_tenant_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.JfrogProjectDetails)
  })
_sym_db.RegisterMessage(JfrogProjectDetails)

JfrogTenantSpec = _reflection.GeneratedProtocolMessageType('JfrogTenantSpec', (_message.Message,), {
  'DESCRIPTOR' : _JFROGTENANTSPEC,
  '__module__' : 'qwak.administration.account.v1.jfrog_tenant_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.JfrogTenantSpec)
  })
_sym_db.RegisterMessage(JfrogTenantSpec)

JfrogProjectSpec = _reflection.GeneratedProtocolMessageType('JfrogProjectSpec', (_message.Message,), {
  'DESCRIPTOR' : _JFROGPROJECTSPEC,
  '__module__' : 'qwak.administration.account.v1.jfrog_tenant_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.JfrogProjectSpec)
  })
_sym_db.RegisterMessage(JfrogProjectSpec)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.account.v1P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0'
  _JFROGTENANTDETAILS._serialized_start=94
  _JFROGTENANTDETAILS._serialized_end=225
  _JFROGPROJECTDETAILS._serialized_start=227
  _JFROGPROJECTDETAILS._serialized_end=269
  _JFROGTENANTSPEC._serialized_start=271
  _JFROGTENANTSPEC._serialized_end=387
  _JFROGPROJECTSPEC._serialized_start=389
  _JFROGPROJECTSPEC._serialized_end=428
# @@protoc_insertion_point(module_scope)
